//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useState } from "react";
import { map, isNil } from "lodash";
import { COLORS } from "primeobjects-helper-util/build/cjs/colors";
import Tooltip from "../../controls/antd/tooltip";
import { usePrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
import { SVG } from "primeobjects-ui-web-basic/build/cjs/controls/svg";
export var CATEGORIES_OPTION = {
    tooltip: "Categories",
    iconSrc: "/icons/platform/categories.svg",
    id: "categories",
    entityName: "Category",
    attributeName: "categoryIds",
    type: "tree"
};
export var TAGS_OPTION = {
    tooltip: "Tags",
    iconSrc: "/icons/platform/tags.svg",
    id: "tags",
    type: "tags"
};
export var LISTS_OPTION = {
    tooltip: "Lists",
    iconSrc: "/icons/platform/tiles.svg",
    id: "lists",
    type: "lists"
};
export var ListNavSection = function (props) {
    var showDrawer = props.showDrawer, smallScreen = props.smallScreen;
    var primaryColor = usePrimaryColor();
    var _a = useState(false), close = _a[0], setClose = _a[1];
    var options = props.options && props.options.length > 0
        ? props.options
        : [CATEGORIES_OPTION, TAGS_OPTION, LISTS_OPTION];
    var onToggleClose = function () {
        if (smallScreen)
            return;
        var newClose = !close;
        setClose(newClose);
        props.onToggleClose(newClose);
    };
    return (React.createElement("div", { className: "h-full max-h-full min-h-full flex bg-white flex-col overflow-hidden", style: __assign({ width: 60 }, props.wrapperStyle) },
        React.createElement(Tooltip, { title: "Close drawer", color: primaryColor["400"], placement: "right", className: showDrawer ? "" : "hidden" },
            React.createElement("button", { className: "w-full p-1 border-b border-r", onClick: props.onCloseDrawer, style: { height: 65 } },
                React.createElement("div", { className: "w-full h-full px-3 py-4 bg-gray-50" },
                    React.createElement(SVG, { src: "/icons/platform/x.svg", size: 26, color: COLORS.GRAY["900"] })))),
        React.createElement(Tooltip, { title: close ? "Open filter pane" : "Close filter pane", color: primaryColor["400"], placement: "right", className: showDrawer ? "hidden" : "" },
            React.createElement("button", { className: "w-full p-1 ".concat(close ? "" : "border-r", " border-b ").concat(smallScreen ? "cursor-not-allowed" : ""), onClick: onToggleClose, style: { height: 65 } },
                React.createElement("div", { className: "w-full h-full px-3 py-4 bg-gray-50 ".concat(smallScreen ? "" : "hover:shadow-lg") },
                    React.createElement(SVG, { src: close
                            ? "/icons/platform/pane-right-arrow.svg"
                            : "/icons/platform/pane-left-arrow.svg", size: 26, color: !smallScreen
                            ? COLORS.GRAY["900"]
                            : COLORS.GRAY["300"] })))),
        !isNil(props.currentId) &&
            map(options, function (option, index) {
                var isCurTab = props.currentId == option.id;
                return (React.createElement(Tooltip, { key: index, title: option.tooltip, color: option.disabled
                        ? COLORS.GRAY["400"]
                        : primaryColor["400"], placement: "right" },
                    React.createElement("div", { className: "w-full pt-1 ".concat(isCurTab ? "py-1 pl-1" : "px-1 border-r", " ").concat(option.disabled
                            ? "cursor-not-allowed"
                            : "cursor-pointer"), onClick: option.disabled
                            ? function () { }
                            : function () { return props.onSelectOption(option); }, style: { height: 65 } },
                        React.createElement("div", { className: "w-full h-full px-3 py-4 ".concat(isCurTab
                                ? "border-".concat(primaryColor.name, "-400 border-l-4 shadow-lg")
                                : "bg-gray-50 hover:shadow-lg") },
                            React.createElement(SVG, { src: option.iconSrc, size: 26, color: isCurTab
                                    ? primaryColor["600"]
                                    : COLORS.GRAY["900"] })))));
            }),
        !close && React.createElement("div", { className: "flex-1 border-r" })));
};
export default ListNavSection;
//# sourceMappingURL=nav.js.map